define([
	"dojo/_base/declare",
    "dojo/promise/all",
    "aps/Memory",
    "aps/Tile",
    "aps/Container",
    "aps/Output",
    "aps/xhr",
	"aps/nav/ViewPlugin"
], function (declare, all, Memory, Tile, Container, Output, xhr, ViewPlugin) {

    function removeService(tile, userId, vpses) {
        tile.set("isBusy", true);
        all(vpses.data.map(function(vps) {
            return xhr('/aps/2/resources/' + vps.aps.id, {
                method: 'DELETE'
            });
        })).then(function () {
            tile.removeAll();
            tile.set({
                onClick: function() {
	                aps.apsc.gotoView("http://aps-standard.org/samples/event-mgmt#vps-wizard", null, {
	                    userId: userId	// You may send a number of parameters available as aps.context.params
	                });
                },
                isBusy: false
            });
            tile.addChild(new Output({"value": "Click to assign a VPS to the user"}));
		});
    }

	return declare(ViewPlugin, {
		init: function (mediator) {
            mediator.setServiceData = function (data) {
                
                var userId = aps.app.model.aps.id,
					vpses = new Memory({data: [], idProperty: "aps.id"}),
					cpu = 0,
					ram = 0,
					disk = 0,
					services = data.services,
					simpleOutput = new Output({
                        value: "Click to see the full list of VPSes"
                    }),
	                tile = new Tile({
	                    gridSize: "md-4 xs-12",
	                    title: "Virtual Servers",
	                    onClick: function() {
	                        aps.apsc.gotoView("http://aps-standard.org/samples/event-mgmt#servers");
	                    }
	                });
                
                tile.addChild(simpleOutput);
                
                services.forEach(function(service) {
                   if(service.aps.type === "http://aps-standard.org/samples/event-mgmt/vps/1.0") {
						vpses.data.push(service);
						cpu += service.hardware.CPU.number;
						ram += service.hardware.memory;
						disk += service.hardware.diskspace;
                   }
                });
				if(vpses.data.length > 0) {
					var container = new Container();
					container.addChild(
						new Output({
							vps: vpses.data.length,
							cpu: cpu,
							ram: ram,
							disk: disk,
							content: "VPSes: ${vps} <br/> CPU: ${cpu} cores <br/> Memory: ${ram} MB <br/> Disk space: ${disk} GB"
					}));
					tile.addChild(container);
                }
				tile.set("buttons", [
				    {
						title: "Actions",
						items: [
							{
								iconClass: "fa-plus-circle",
								title: "Assign a VPS",
								onClick: function() {
									aps.apsc.gotoView("http://aps-standard.org/samples/event-mgmt#vps-wizard",
										null, {userId: userId});
								}
							},
							{
								icon: "fa-minus-circle",
								title: "Remove VPSes",
								onClick: function() {
									removeService(tile, userId, vpses);
								}
							}
						]
				    }
				]);

				return tile;
			};	// End of mediator.setServiceData
		}	// End of Init
	});		// End of Declare
});			// End of Define

