define([
   "dojo/_base/declare",
   "dojo/when",
   "aps/View",
   "aps/ResourceStore",
   "./displayError"
], function (declare, when, View, Store, displayError) {
   var subscriptionId;

   return declare(View, {
      init: function() {
         /* Display explanations about the process driven by the wizard */
		return ["aps/Panel", {
			id: "wizard_panel"
		},
		[["aps/Output", {
			id: "wizard_contents",
			content: "<h2>Let's create one more server </h2>"  +
			"Before getting started, make sure you have all necessary parameters: <br>" +
			"<ul> <li> CPU power - number of CPU cores" +
			"<li> Disk space - GB" +
			"<li> RAM space - MB"
		}]]];
      },

      onContext: function(context) {
			/* Make all views plugged into the wizard visible */
			subscriptionId = context.vars.context.aps.subscription;
			aps.context.wizardState.forEach(function(view) {
					view.visible = true;
				}
			);
			aps.apsc.wizardState(aps.context.wizardState);

			aps.apsc.hideLoading();
      },

      onNext: function() {
			/* Direct a user to the first view */
			if (aps.context.params.userId) { // If we've come here from the User Manager
				aps.apsc.next(aps.context.params.userId);
			}

			else aps.apsc.next();
      },

      onSubmit: function() {
			/* Specify the subscription whose resource will be used */
			aps.context.subscriptionId = subscriptionId;

			/* Create the data store */
			var store = new Store({
				apsType: "http://aps-standard.org/samples/event-mgmt/vps/1.0",
				target: "/aps/2/resources/"
			});

			/* Receive data from the last step and save the new VPS */
			var newVPS =
				aps.context.wizardData["http://aps-standard.org/samples/event-mgmt#server-new-last"];
			when(store.put(newVPS),
				function() {
					aps.apsc.gotoView("servers");
				},
				displayError
			);
	  },

      onCancel: function() {
			/* Forward a user to the list of servers */
			aps.apsc.gotoView("servers");
      }

   });
});
