define([
   "dojo/_base/declare",
   "dojo/when",
   "dojox/mvc/at",
   "dojox/mvc/getStateful",
   "dojo/promise/all",
   
   "aps/View",
   "aps/Memory",
   "aps/ResourceStore",
   
   /* Include JSON files that defines the default properties */
   "aps/json!./newvps.json",
   "aps/json!app/newoffer.json"
],
function (declare, when, at, getStateful, all, View, Memory, Store, newVPS, newOffer) {
	var self;
	return declare(View, {
		init: function() {
			self = this;
			/* Declare data sources */
			self.userSelectionList = new Memory({data: [], idProperty: "aps.id"});
			self.offerCache = new Memory({
			   data: [],
			   idProperty: "aps.id"
			});
			self.offerCtrl = getStateful({
			   data: newOffer
			});
			self.vpsModel = getStateful({"data": newVPS});

			function onChangeOffer(offerID) {
			   console.log("Offer ID is changing for: " + offerID); // For debugging only
			   when(self.offerCache.get(offerID), function(data) {
			      self.offerCtrl.data.set(data);  // Update the current offer
			   });
			}
			
			/* Define and return widgets */
			return ["aps/Panel", {id: this.genId("srvNew_form")}, [
	           ["aps/FieldSet", {title: "General"}, [
	                ["aps/TextBox", {
	                    label: "Server Name",
	                    value: at(self.vpsModel.data, "name"),
	                    required: true
	                }],
	                ["aps/TextBox", {
	                    label: "Description",
	                    value: at(self.vpsModel.data, "description")
	                }]
	           ]],
	           ["aps/Panel", {id: this.genId("srvNew1_offers_panel"), title: "Offering"}, [
					["aps/FieldSet", {id: this.genId("srvNew1_offers")}, [
						["aps/Select", {
							id: self.genId("srvNew1_offerSelect"),
							gridSize: 'md-3 xs-12',
							store: self.offerCache,
							required: true,
							label: "Service profile:",
							onChange: onChangeOffer,
							labelAttr: "name",
							value: at(self.vpsModel.data.offer.aps, "id")
						}],
						["aps/Select", {
							id: this.genId("srvNew1_userSelect"),
							gridSize: 'md-3 xs-12',
							label: _("VPS Owner"),
							store: self.userSelectionList,
							labelAttr: "fullName",
							value: at(self.vpsModel.data.user.aps, "id"),
							required: true
						}]
					]]
				]],
				["aps/Panel", {id: this.genId("srvNew1_vps_configuration"), title: "Server Configuration"}, [
		           ["aps/FieldSet", {id: "srvNew1_config"}, [
						["aps/Output", {
						id: this.genId("new1_os"),
						label: "Operating System:",
						value: at(self.offerCtrl.data.platform.OS, "name")
						}],
						["aps/Spinner", {
		                    label:  "CPU Number",
							gridSize: 'md-3 xs-12',
		                    minimum: 1,
		                    maximum: at(self.offerCtrl.data.hardware.CPU, "number"),
		                    value: at(self.vpsModel.data.hardware.CPU, "number"),
		                    step: 1
		                }],
		                ["aps/Spinner", {
		                    label: "Disk Space",
							gridSize: 'md-3 xs-12',
		                    minimum: 1,
		                    maximum: at(self.offerCtrl.data.hardware, "diskspace"),
		                    value: at(self.vpsModel.data.hardware, "diskspace"),
		                    legend: "Gb",
		                    step: 1
		                }],
		                ["aps/Spinner", {
		                    label: "RAM",
							gridSize: 'md-3 xs-12',
		                    minimum: 128,
		                    maximum: at(self.offerCtrl.data.hardware, "memory"),
		                    value: at(self.vpsModel.data.hardware, "memory"),
		                    legend: "Mb",
		                    step: 128
		                }]
		           ]]
	           ]]
	        ]];
		},

		/* Additional single-page view flow method */
		onContext: function() {
			 if (typeof aps.context.wizardData === 'undefined' ||
                    !aps.context.wizardData["http://aps-standard.org/samples/event-mgmt#server-new-1"]) {
                var offerStore = new Store({ // The list of offers for selection
                    apsType: "http://aps-standard.org/samples/event-mgmt/offer/1.0",
                    target: "/aps/2/resources/"
                });
                var userStore = new Store({    // The list of users for selection
                    apsType: "http://aps-standard.org/types/core/user/1.0",
                    target: "/aps/2/resources/"
                });

                all([offerStore.query(), userStore.query()]).then(function(offersAndUsers) {
                    var offers = offersAndUsers[0];
                    if (offers.length === 0) return;
                    var users = offersAndUsers[1];
                    self.userSelectionList.setData(users);

                    self.offerCache.setData(offers);
                    if (aps.app.isNew !== false) {
                        self.offerCtrl.data.set(offers[0]);
                    }
                    if (aps.context.wizardData["http://aps-standard.org/samples/event-mgmt#vps-wizard"]) {
                        self.vpsModel.data.user.aps.set(
                            "id",
                            aps.context.wizardData["http://aps-standard.org/samples/event-mgmt#vps-wizard"]
                        );
                    }
                    self.vpsModel.data.offer.aps.set("id", self.offerCtrl.data.aps.id);
                    self.byId("srvNew1_userSelect").set("store", self.userSelectionList);
                    self.byId("srvNew1_offerSelect").set("store", self.offerCache);
                }).then(function() {
                    aps.apsc.hideLoading();
                });
			 }
			 else aps.apsc.hideLoading();
		},

		/* Create handlers for the navigation buttons */

		onNext: function() {
			if (!self.userSelectionList.data.length) {
				aps.apsc.cancelProcessing();
				return;
			}
			var page = this.byId("apsPageContainer");
			page.get("messageList").removeAll();
			if (!page.validate()) {
				aps.apsc.cancelProcessing();
				return;
			}
			self.vpsModel.data.set("userName", self.userSelectionList.get(self.vpsModel.data.user.aps.id).fullName);

		    self.vpsModel.data.platform.OS.set("name", self.offerCtrl.data.platform.OS.name);
		    /* Proceed to the next screen */
		    aps.apsc.next(self.vpsModel.data);
		},
		
		onPrev: function() {
			aps.apsc.prev();
		}
	
	});
});
